## 1. How to Build a Simple API in SvelteKit

In this article, you will learn how to build a REST API with CRUD functionalities in TypeScript using the SvelteKit framework. This marks the first part of a two-part series where we'll create a full-stack feedback application. In this installment, our focus will be on creating the API aspect of the feedback application. In the subsequent tutorial, we'll tackle the frontend part, enabling it to interact seamlessly with the API.

![How to Build a Simple API in SvelteKit](https://codevoweb.com/wp-content/uploads/2023/07/How-to-Build-a-Simple-API-in-SvelteKit.webp)

### Topics Covered

- Running the SvelteKit App on Your Machine
- Setting up the SvelteKit Application
- Setting up a PostgreSQL Database
    - Using a Cloud Platform
    - Optional: Using Docker
- Setting up Prisma ORM for Database Access
- Creating a Singleton Prisma Client
- Creating the SvelteKit API Endpoints
    - GET /hello: Returns a Simple Message in JSON
    - GET /feedbacks: Fetches a Paginated List of Feedback
    - POST /feedbacks: Adds a New Feedback
    - GET /feedbacks/[id]: Retrieves a Single Feedback by ID
    - PATCH /feedbacks/[id]: Edits a Feedback by ID
    - DELETE /feedbacks/[id]: Deletes a Feedback by ID
- Conclusion

Read the entire article here: [https://codevoweb.com/how-to-build-a-simple-api-in-sveltekit/](https://codevoweb.com/how-to-build-a-simple-api-in-sveltekit/)


## 2. Build a Frontend App in SvelteKit using a RESTful API

In this article, you will learn how to build a feedback application in SvelteKit using a REST API. Specifically, we will be creating the UI that interacts with the REST API we built for the feedback application in the previous tutorial.

![Build a Frontend App in SvelteKit using a RESTful API](https://codevoweb.com/wp-content/uploads/2023/07/Building-an-Application-in-SvelteKit-using-a-RESTful-API.webp)

### Topics Covered

- Running the Full-Stack SvelteKit App on Your Machine
- Setting Up the SvelteKit Project
- Setting Up Tailwind CSS
- Adding Toast Notification
- Creating the Application Store
- Creating the Feedback Rating Component
- Creating the Feedback Form Component
- Creating the Feedback Statistics Component
- Creating the Feedback Item Component
- Loading the Feedback Data
- Rendering the Svelte Components in a Page File
- Conclusion

Read the entire article here: [https://codevoweb.com/build-a-frontend-app-in-sveltekit-using-a-restful-api/](https://codevoweb.com/build-a-frontend-app-in-sveltekit-using-a-restful-api/)


